package rpmfile

  1. Overview
  2. Docs

Module RpmfileSource

A pure OCaml library for parsing RPM files (supports V3 and partly V4 package versions).

Package

The Rpmfile does not provide a single "package type", but instead it provides Metadata.t and Payload.t, which you can use to compose the package in the way you need.

Sourcemodule Metadata : sig ... end

RPM package's metadata.

Sourcemodule Payload : sig ... end

The module for work with RPM package's payload.

Content viewing

Sourcemodule View : sig ... end

The module for viewing the contents of RPM package metadata (Metadata.t) and decoding Metadata.Header_structure values into OCaml values allows you to find values by their tags, either by their number or by name.

Reader

Powered by Bytream library.

Sourcemodule Reader : sig ... end

The module provides functions to read RPM packages from incoming byte streams.