Page
Library
Module
Module type
Parameter
Class
Class type
Rpmfile.ReaderSourceThe module provides functions to read RPM packages from incoming byte streams.
Short alias to incoming byte stream.
from_channel_without_payload ic
Similar to input_package_without_payload, but for channels.
from_channel_with_payload ic
Similar to from_channel_without_payload, but returns payload with metadata.
input_metadata_only in_stream
Input only package's metadata from incoming byte stream, without skipping payload. The remaining payload is available for the user to analyze on their own.
See also
input_package_without_payload.input_metadata_with and input_package_with...payload. It's very important, because the value of the RPMTAG_PAYLOADSIZE tag is not just the payload size, but also includes the size of the package header plus the payload.input_package_without_payload in_stream
Similar to the input_metadata_only function, but skip the payload section from the stream's source.
input_metadata_with in_stream f
Input the package's metadata and call the f function to handle the payload section of the package.
Example
Rpmfile.Reader.input_metadata_with in_stream
@@ fun metadata payload_size ->
(* ... *)input_package_with_string_payload in_stream
input_package_with_bigstring_payload in_stream